
#ifndef _C12_co590_
#define _C12_co590_

#ifdef __cplusplus
extern "C" {
#endif

extern void F415_2672(EIF_REFERENCE);
extern void EIF_Minit590(void);
extern long O2402[];

#ifdef __cplusplus
}
#endif

#endif
